package csc.jms.cluster.ejb;

import javax.annotation.Resource;
import javax.ejb.ActivationConfigProperty;
import javax.ejb.MessageDriven;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import org.jboss.ejb3.annotation.ResourceAdapter;

@MessageDriven(activationConfig = {
		@ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Queue"),
		@ActivationConfigProperty(propertyName = "destination", propertyValue = "queue/requestQ"),
		@ActivationConfigProperty(propertyName = "acknowledgeMode", propertyValue = "Auto-acknowledge") })
@ResourceAdapter("hornetq-ra.rar")

public class MDB1 implements MessageListener {

	@Resource(mappedName = "java:RemoteJmsXA")
	private ConnectionFactory connectionFactory;

	public MDB1() {
	}

	public void onMessage(Message message) {
		try {
			System.out.println("message consumed by mdb : " + message);
			sendResponse("Message received");
		}

	private void sendResponse(String message) {
		// Step 5. Create a connection to a remote server using a
		// connection-factory (look at the deployed file jms-remote-ds.xml)

		System.out.println("0. About to send the response message");

		Connection conn;
		try {
			conn = connectionFactory.createConnection();
			System.out.println("1. created connection");

			// Step 6. Send a message to a QueueA on the remote server, which
			// will be received by MDBQueueA
			Session sess = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
			System.out.println("2. created session");
			
			Queue destQueueA = sess.createQueue("responseQ");
			System.out.println("3. created queue");
			
			MessageProducer prodA = sess.createProducer(destQueueA);
			System.out.println("4. created producer");
			
			prodA.send(sess.createTextMessage(message));
			System.out.println("Sent message \"" + message + "\" to responseQ");

			// Step 7. Close the connection. (Since this is a JCA connection,
			// this will just place the connection back to a connection pool)
			conn.close();
		} catch (JMSException e) {
			e.printStackTrace();
		}
	}
}